@@ -681,6 +681,102 @@ test_that("group sizes works with group_factor with method l_starts", {
   )
 })
 
+test_that("group sizes works with group_factor with method every", {
+  xpectr::set_test_seed(1)
+
+  v <- c(1:17)
+
+  gf <- group_factor(v, n = 5, method = "every")
+
+
+  ## Testing 'gf'                                                           ####
+  ## Initially generated by xpectr
+  xpectr::set_test_seed(42)
+  # Testing is factor
+  expect_true(
+    is.factor(gf))
+  # Testing values
+  expect_equal(
+    as.character(gf),
+    c("1", "2", "3", "4", "5", "1", "2",
+      "3", "4", "5", "1", "2", "3",
+      "4", "5", "1", "2"),
+    fixed = TRUE)
+  # Testing names
+  expect_equal(
+    names(gf),
+    NULL,
+    fixed = TRUE)
+  # Testing length
+  expect_equal(
+    length(gf),
+    17L)
+  # Testing number of levels
+  expect_equal(
+    nlevels(gf),
+    5L)
+  # Testing levels
+  expect_equal(
+    levels(gf),
+    c("1", "2", "3", "4", "5"),
+    fixed = TRUE)
+  ## Finished testing 'gf'                                                  ####
+
+
+  # Expect only 17 - (17 %% 3) = 15 elements after force_equal
+  gf <- group_factor(v, n = 3, method = "every", force_equal = TRUE)
+
+
+  ## Testing 'gf'                                                           ####
+  ## Initially generated by xpectr
+  xpectr::set_test_seed(42)
+  # Testing is factor
+  expect_true(
+    is.factor(gf))
+  # Testing values
+  expect_equal(
+    as.character(gf),
+    c("1", "2", "3", "1", "2", "3", "1",
+      "2", "3", "1", "2", "3", "1",
+      "2", "3"),
+    fixed = TRUE)
+  # Testing names
+  expect_equal(
+    names(gf),
+    NULL,
+    fixed = TRUE)
+  # Testing length
+  expect_equal(
+    length(gf),
+    15L)
+  # Testing number of levels
+  expect_equal(
+    nlevels(gf),
+    3L)
+  # Testing levels
+  expect_equal(
+    levels(gf),
+    c("1", "2", "3"),
+    fixed = TRUE)
+  ## Finished testing 'gf'                                                  ####
+
+  # Test group counts for a variety of settings
+  v <- c(1:57)
+
+  group_counts <- function(v, n) {
+    gf <- group_factor(v, n, method = "every")
+    counts <- plyr::count(gf)
+    counts$freq
+  }
+
+  expect_equal(group_counts(v, 2), c(29, 28))
+  expect_equal(group_counts(v, 3), c(19, 19, 19))
+  expect_equal(group_counts(v, 4), c(15,14,14,14))
+  expect_equal(group_counts(v, 5), c(12, 12, 11, 11, 11))
+  expect_equal(group_counts(v, 0.15), c(8, 7, 7, 7, 7, 7, 7, 7))
+
+})
+
 test_that("l_starts raises error correctly when value is not found", {
   xpectr::set_test_seed(1)
 
@@ -1997,7 +2093,6 @@ test_that("fuzz testing input checks for l_starts method in group_factor()", {
 
 })
 
-
 test_that("group_factor() works with group_by()", {
   xpectr::set_test_seed(42)
 
